# Scrouter

A tool that looks for relations between users.

## Installing

Via pip:

```
pip install ky.scrouter
```

You can also update to the latest version:

```
pip install ky.scrouter --upgrade
```

**Make sure you have Python 3.8 or above installed!**

## Program launch

Via terminal:

```
python -m ky.scrouter
```

## License
This project follows MIT license (see [LICENSE](LICENSE)).
